<?php
class Dukapress_Downloads{

    static function init(){
        add_action( 'pre_get_posts', array( __CLASS__, 'include_out_of_stock_products_for_downloads' ) );
        add_filter( 'posts_results', array( __CLASS__, 'out_of_stock_product_downloads' ), 10, 2 );
        add_action( 'template_redirect', array( __CLASS__, 'download' ) );
    }


    static function include_out_of_stock_products_for_downloads( $query ) {
        global $dukapress;
		if ( 'duka' == $query->get( 'post_type' ) && $query->get( 'duka' ) && isset( $_GET[ 'orderid' ] ) && ($order = $dukapress->get_order( $_GET[ 'orderid' ] )) ) {
			$query->set( 'post_status', array( 'out_of_stock', 'publish' ) );
		}
	}
    
    /**
     * Check if a product is digital. Mostly used to prevent shipping costs on the item
     */
    static function is_digital_file($product_id){
        $url = get_post_meta( $product_id, 'digital_file', true );
		if ( !$url )
			return false;
        else
            return true;
    }


    /**
     * Function called to send Download
     */
    static function download() {
		global $wp_query, $dukapress;

		if ( 'duka' == $wp_query->get( 'post_type' ) && $wp_query->get( 'duka' ) && isset( $_GET[ 'orderid' ] ) && ($order = $dukapress->get_order( $_GET[ 'orderid' ] )) ) {
			$product_id = get_queried_object_id();
			self::serve_download( $product_id );
		}
	}


    static function out_of_stock_product_downloads( $posts, $query ) {
        global $dukapress;
		if ( 'duka' == $query->get( 'post_type' ) && $query->get( 'duka' ) && isset( $_GET[ 'orderid' ] ) && ($order = $dukapress->get_order( $_GET[ 'orderid' ] )) ) {
			$posts[ 0 ]->post_status = 'publish';
		}

		return $posts;
	}


    //returns formatted download url for a given product. Returns false if no download
	static function get_download_url( $product_id, $order_id ) {
		$url = get_post_meta( $product_id, 'digital_file', true );
		if ( !$url )
			return false;

		return add_query_arg( 'orderid', $order_id, get_permalink( $product_id ) );
	}
    
    /**
    * Serve Downloads
    *
    */
    static function serve_download($product_id) {
        global $dukapress;
        if (!isset($_GET['orderid']))
            return false;

        //get the order
        $order = $dukapress->get_order($_GET['orderid']);

        if (!$order)
            wp_die(__('Sorry, the link is invalid for this download.', 'dp-lang'));

        //check that order is paid
        if ($order->post_status == 'order_received')
            wp_die(__('Sorry, your order has been marked as unpaid.', 'dp-lang'));

        $url = get_post_meta($product_id, 'digital_file', true);
        $downloaded = get_post_meta($product_id, 'downloaded', true);

        if (!$url)
            wp_die(__('Whoops, we were unable to find the file for this download. Please contact us for help.', 'dp-lang'));

        //check for too many downloads
        $max_downloads = $dukapress->get_setting('max_downloads', 3);
        if (intval($downloaded) >= $max_downloads)
            wp_die(sprintf(__("Sorry, our records show you've downloaded this file %d out of %d times allowed. Please contact us if you still need help.", 'dp-lang'), intval($download['downloaded']), $max_downloads));

        //for plugins to hook into the download script. Don't forget to increment the download count, then exit!
        do_action('duka_serve_download', $url, $order, $download);

        //allows you to simply filter the url
        $url = apply_filters('duka_download_url', $url, $order, $download);

        set_time_limit(0);
        //try to prevent script from timing out
        //create unique filename
        $ext = ltrim(strrchr(basename($url), '.'), '.');
        $filename = sanitize_file_name(strtolower(get_the_title($product_id)) . '.' . $ext);

        $dirs = wp_upload_dir();
        $location = str_replace($dirs['baseurl'], $dirs['basedir'], $url);
        if (file_exists($location)) {

            // File is in our server
            $tmp = $location;
            $not_delete = true;
        }
        else {

            // File is remote so we need to download it first
            require_once (ABSPATH . '/wp-admin/includes/file.php');

            //don't verify ssl connections
            add_filter('https_local_ssl_verify', create_function('$ssl_verify', 'return false;'));
            add_filter('https_ssl_verify', create_function('$ssl_verify', 'return false;'));

            $tmp = self::download_url($url);
            //we download the url so we can serve it via php, completely obfuscating original source

            if (is_wp_error($tmp)) {
                @unlink($tmp);
                trigger_error("Dukapress was unable to download the file $url for serving as download: " . $tmp->get_error_message(), E_USER_WARNING);
                wp_die(__('Whoops, there was a problem loading up this file for your download. Please contact us for help.', 'dp-lang'));
            }
        }

        if (file_exists($tmp)) {
            $chunksize = (8 * 1024);
            //number of bytes per chunk
            $buffer = '';
            $filesize = filesize($tmp);
            $length = $filesize;
            list($fileext, $filetype) = wp_check_filetype($tmp);

            if (empty($filetype)) {
                $filetype = 'application/octet-stream';
            }

            ob_clean();
            //kills any buffers set by other plugins

            if (isset($_SERVER['HTTP_RANGE'])) {

                  //partial download headers
                  preg_match('/bytes=(\d+)-(\d+)?/', $_SERVER['HTTP_RANGE'], $matches);
                  $offset = intval($matches[1]);
                  $length = intval($matches[2]) - $offset;
                  $fhandle = fopen($filePath, 'r');
                  fseek($fhandle, $offset);
                  // seek to the requested offset, this is 0 if it's not a partial content request
                  $data = fread($fhandle, $length);
                  fclose($fhandle);
                  header('HTTP/1.1 206 Partial Content');
                  header('Content-Range: bytes ' . $offset . '-' . ($offset + $length) . '/' . $filesize);
            }

            header('Accept-Ranges: bytes');
            header('Content-Description: File Transfer');
            header('Content-Type: ' . $filetype);
            header('Content-Disposition: attachment;filename="' . $filename . '"');
            header('Expires: -1');
            header('Cache-Control: public, must-revalidate, post-check=0, pre-check=0');
            header('Pragma: public');
            header('Content-Length: ' . $filesize);

            if ($filesize > $chunksize) {
                $handle = fopen($tmp, 'rb');

                if ($handle === false) {
                    trigger_error("Dukapress was unable to read the file $tmp for serving as download.", E_USER_WARNING);
                    return false;
                }

                while (!feof($handle) && (connection_status() === CONNECTION_NORMAL)) {
                    $buffer = fread($handle, $chunksize);
                    echo $buffer;
                }

                ob_end_flush();
                fclose($handle);
            }
            else {
                ob_clean();
                flush();
                readfile($tmp);
            }

            if (!$not_delete) {
                @unlink($tmp);
            }
        }
        $downloaded = intval($downloaded) + 1;
        update_post_meta($order->ID, 'downloaded', $downloaded);
        exit;
    }
}
?>
