<?php
if(!class_exists('DukaPress_Mail')) {

  /**
   * Dukapress Mail
   * Handles All mail functions used in the plugin
   *
   */
  class DukaPress_Mail{

    /**
     * Send the low stock mail to the admin
     * @param Integer $productid
     * @param Integer $stock
     */
    static function low_stock_notification($productid, $stock){
        global $dukapress;
        $enabled = $dukapress->get_setting( 'mail->inventory->enabled' );
        if($enabled){
            $mail_to = $dukapress->get_setting( 'mail->inventory->to' );
            $mail_subject = $dukapress->get_setting( 'mail->inventory->subject' );
            $mail_body = $dukapress->get_setting( 'mail->inventory->body' );
            $product = get_post($productid);

            $array1 = array('%pno%', '%pname%', '%stock%');
            $array2 = array($productid, $product->post_name, $stock);

            $mail_subject = str_replace($array1, $array2, $mail_subject);
            $mail_body = str_replace($array1, $array2, $mail_body);
            self::send_mail($mail_to,$mail_subject,$mail_body);
        }
    }
      
    /**
     * Enquiry Mail
     */
    static function enquiry_mail($cart, $name, $email, $subject, $message){
        global $dukapress;
        $enabled = $dukapress->get_setting( 'mail->enquiry->enabled' );
        if($enabled){
            $mail_to = $dukapress->get_setting( 'mail->enquiry->to' );
            $mail_subject = $dukapress->get_setting( 'mail->enquiry->subject' );
            $mail_body = $dukapress->get_setting( 'mail->enquiry->body' );
            
            $content = '<h2 class="title"><strong>'.__("Product Information","dp-lang").'</strong></h2>';
            $content .= '<table width="100%" border="0" class="widefat">';
            $content .= '<thead>';
            $content .= '<tr>';
            $content .= '<th align="left" scope="col">'.__("Name","dp-lang").'</th>';
            $content .= '<th align="left" scope="col">'.__("Quantity","dp-lang").'</th>';
            $content .= '<th align="left" scope="col">'.__("Unit Price","dp-lang").'</th>';
            $content .= '<th align="left" scope="col">'.__("Total Price","dp-lang").'</th>';
            $content .= '</tr>';
            $content .= '</thead>';
            $content .= '<tbody>';
            foreach ($cart as $key => $dpsc_product) {
                $dpsc_var = '';
                if (!empty($dpsc_product['var'])) {
                    $dpsc_var = ' (' . $dpsc_product['var'] . ')';
                }
                $product = get_post($dpsc_product['item_number']);
                $view_link = get_permalink($dpsc_product['item_number']);
                $prod_price = $dpsc_product['price'] * $dpsc_product['quantity'];
                $content .= '<tr>';
                $content .= '<td>';
                $content .= '<a href="'.$view_link.'" target="_blank" title="'.__('View','dp-lang').' '.$product->post_title.'">'.$product->post_title.$dpsc_var.'</a>';
                $content .= '</td>';
                $content .= '<td>'.$dpsc_product['quantity'].'</td>';
                $content .= '<td>'.$this->format_currency( '',$price).'</td>';
                $content .= '<td>'.$this->format_currency( '', $prod_price ).'</td>';
                $content .= '</tr>';
            }
            $content .= '</tbody>';
            $content .= '</table>';

            $array1 = array('%from%', '%from_email%', '%enq_subject%', '%details%', '%custom_message%');
            $array2 = array($name, $email, $subject,$content,$message);

            $mail_subject = str_replace($array1, $array2, $mail_subject);
            $mail_body = str_replace($array1, $array2, $mail_body);
            self::send_mail($mail_to,$mail_subject,$mail_body);
        }
    }


    /**
     * New Order Notification Mail
     *
     */
    static function new_order_notification($user_info, $shipping_info, $order_id) {
        global $dukapress;
        $enabled = $dukapress->get_setting( 'mail->order_placed->enabled' );
        if($enabled){     
            $fname = "";
            $lname = "";
			
			$order = $dukapress->get_order($order_id);
            
            $item_index =  array_search('dpsc_firstname', array_column($user_info, 'uname'));
            if($item_index !== FALSE ){
                $fname = $user_info[$item_index]['value'];
            }
            $item_index =  array_search('dpsc_lastname', array_column($user_info, 'uname'));
            if($item_index !== FALSE ){
                $lname  = $user_info[$item_index]['value'];
            }
            
            $email =  array_search('dpsc_email', array_column($user_info, 'uname'));
            
            $attachment = false;
            $create_pdf = $dukapress->get_setting( 'pdf_generation' );
            if($create_pdf){
                $attachment = DukaPress_PDF::make_pdf($order_id);
            }

            $userdetails = $dukapress->user_info_to_string($user_info,$shipping_info);
            $orderdetails = $dukapress->order_info_to_string($order);

            $site_url = site_url();
            $shop_name = $dukapress->get_setting( 'shop_name' );
            
            $order_url = dukapress_page_url(false, 'order');
            $check_return_path = explode('?', $order_url);
            if (count($check_return_path) > 1) {
                $order_url .= '&orderid=1'.$order_id;
            } else {
                $order_url .= '?orderid='.$order_id;
            }

            $find = array('%fname%','%lname%','%userdetails%','%inv%', '%siteurl%', '%shop%','%order-details% ','%order-log-transaction%');
            $replace = array($fname,$lname,$userdetails, $order_id, $site_url, $shop_name,$orderdetails,$order_url);

            $admin_mail_to = $dukapress->get_setting( 'mail->order_placed->admin->to' );
            $admin_mail_subject = $dukapress->get_setting( 'mail->order_placed->admin->subject' );
            $admin_mail_body = $dukapress->get_setting( 'mail->order_placed->admin->body' );
            
            $admin_mail_subject = str_replace($find, $replace, $admin_mail_subject);
            $message = str_replace($find, $replace, $admin_mail_body);

            self::send_mail($admin_mail_to, $admin_mail_subject, $message, $admin_mail_to , $shop_name, $attachment); //Send admin mail

            $user_mail_from = $dukapress->get_setting( 'mail->order_placed->user->from' );
            $user_mail_subject = $dukapress->get_setting( 'mail->order_placed->user->subject' );
            $user_mail_body = $dukapress->get_setting( 'mail->order_placed->user->body' );
            
            $user_mail_subject = str_replace($find, $replace, $user_mail_subject);
            $message = str_replace($find, $replace, $user_mail_body);
            
            
            if($email !== FALSE ){
                $em = $user_info[$email]['value'];
                self::send_mail($em,  $user_mail_subject, $message, $user_mail_from , $shop_name, $attachment); //Send user mail
                
            }else{
                //No email to the user. Sad
            }
        }
    }
      
      
    /**
     * Cancelled Order
     */
    static function cancelled_order_notification($order_id) {
        global $dukapress;
        $enabled = $dukapress->get_setting( 'mail->order_cancelled->enabled' );
        if($enabled){
            $order = $dukapress->get_order($order_id);
            $meta = get_post_custom($order->ID);
            //unserialize
            foreach ($meta as $key => $val)
                $meta[$key] = array_map('maybe_unserialize', $val);
            
            $user_info = $meta["dpsc_user_info"][0];
            $shipping_info = $meta["dpsc_shipping_info"][0];
            
            $fname = "";
            $lname = "";
            
            $item_index =  array_search('dpsc_firstname', array_column($meta["dpsc_user_info"][0], 'uname'));
            if($item_index !== FALSE ){
                $fname = $meta["dpsc_user_info"][0][$item_index]['value'];
            }
            $item_index =  array_search('dpsc_lastname', array_column($meta["dpsc_user_info"][0], 'uname'));
            if($item_index !== FALSE ){
                $lname  = $meta["dpsc_user_info"][0][$item_index]['value'];
            }

            $userdetails = $dukapress->user_info_to_string($user_info,$shipping_info);
            $orderdetails = $dukapress->order_info_to_string($order);

            $site_url = site_url();
            $shop_name = $dukapress->get_setting( 'shop_name' );
            $order_url = site_url("admin.php?page=dukapress-shopping-cart-order-log&id=$order_id");

            $find = array('%fname%','%lname%','%userdetails%','%inv%', '%siteurl%', '%shop%','%order-details% ','%order-log-transaction%');
            $replace = array($fname,$lname,$userdetails, $order_id, $site_url, $shop_name,$orderdetails,$order_url);

            $admin_mail_to = $dukapress->get_setting( 'mail->order_cancelled->admin->to' );
            $admin_mail_subject = $dukapress->get_setting( 'mail->order_cancelled->admin->subject' );
            $admin_mail_body = $dukapress->get_setting( 'mail->order_cancelled->admin->body' );

            $admin_mail_subject = str_replace($find, $replace, $admin_mail_subject);
            $message = str_replace($find, $replace, $admin_mail_body);

            self::send_mail($admin_mail_to, $admin_mail_subject, $message, $admin_mail_to , $shop_name); //Send admin mail

            $user_mail_from = $dukapress->get_setting( 'mail->order_cancelled->user->from' );
            $user_mail_subject = $dukapress->get_setting( 'mail->order_cancelled->user->subject' );
            $user_mail_body = $dukapress->get_setting( 'mail->order_cancelled->user->body' );
            
            $user_mail_subject = str_replace($find, $replace, $user_mail_subject);
            $message = str_replace($find, $replace, $user_mail_body);
            $email =  array_search('dpsc_email', array_column($user_info, 'uname'));
            if($email !== FALSE ){
                $em = $user_info[$email]['value'];
                self::send_mail($em,  $user_mail_subject, $message, $user_mail_from , $shop_name); //Send user mail
                
            }else{
                //No email to the user. Sad
            }
        }
    }
      
    /**
     * New User Registration
     */
    static function new_user_registration($username,$password,$email){
        global $dukapress;
        $enabled = $dukapress->get_setting( 'mail->user_registered->enabled' );
        if($enabled){
            $login_url = wp_login_url();
            $shop_name = $dukapress->get_setting( 'shop_name' );
            
            $find = array('%uname%','%pass%','%email%','%login%','%shop%');
            $replace = array($username,$password,$email, $login_url, $shop_name);
            
            $admin_mail_to = $dukapress->get_setting( 'mail->user_registered->admin->to' );
            $admin_mail_subject = $dukapress->get_setting( 'mail->user_registered->admin->subject' );
            $admin_mail_body = $dukapress->get_setting( 'mail->user_registered->admin->body' );

            $admin_mail_subject = str_replace($find, $replace, $admin_mail_subject);
            $message = str_replace($find, $replace, $admin_mail_body);

            self::send_mail($admin_mail_to, $admin_mail_subject, $message, $admin_mail_to , $shop_name); //Send admin mail

            $user_mail_from = $dukapress->get_setting( 'mail->user_registered->user->from' );
            $user_mail_subject = $dukapress->get_setting( 'mail->user_registered->user->subject' );
            $user_mail_body = $dukapress->get_setting( 'mail->user_registered->user->body' );
            
            $user_mail_subject = str_replace($find, $replace, $user_mail_subject);
            $message = str_replace($find, $replace, $user_mail_body);
            
            self::send_mail($email,  $user_mail_subject, $message, $user_mail_from , $shop_name); //Send user mail
        }
    }
      
    /**
     * Payment Mail
     */
    static function payment_mail($order_id){
        global $dukapress;
        $enabled = $dukapress->get_setting( 'mail->payments->enabled' );
        if($enabled){
            $order = $dukapress->get_order($order_id);
            $meta = get_post_custom($order->ID);
            
            foreach ($meta as $key => $val)
                $meta[$key] = array_map('maybe_unserialize', $val);
            

            $site_url = site_url();
            $shop_name = $dukapress->get_setting( 'shop_name' );
            $download_url = "";
            
            $order = $dukapress->get_order($order_id);
            
            $download_content = "";
            $order_status = __('Received', 'dp-lang');
            if ($order->post_status == 'order_received')
                $order_status = __('Received', 'dp-lang');
            else if ($order->post_status == 'order_paid'){
                $order_status = __('Paid', 'dp-lang');                
                $cart = $meta["dpsc_cart_info"][0];
                foreach ($cart as $key => $dpsc_product) {
                    $dpsc_var = '';
                    if (!empty($dpsc_product['var'])) {
                        $dpsc_var = ' (' . $dpsc_product['var'] . ')';
                    }
                    $url = get_post_meta($dpsc_product['item_number'], 'digital_file', true);
                    if($url){
                        $download_url = Dukapress_Downloads::get_download_url($dpsc_product['item_number'], $order_id );
                        if($download_url)
                            $download_content .= '<a href="'.$download_url.'" target="_blank" title="'.__('Download','dp-lang').' '.$dpsc_product['name'].'">'.__("Click Here To Download ","dp-lang").' '.$dpsc_product['name'].$dpsc_var.'</a>';
                    }
                }
                
                
            }
            else if ($order->post_status == 'order_shipped')
                $order_status = __('Shipped', 'dp-lang');
            else if ($order->post_status == 'order_closed')
                $order_status = __('Closed', 'dp-lang');
            else if ($order->post_status == 'trash')
                $order_status = __('Trashed', 'dp-lang');
            
            $fname = "";
            $lname = "";
            $email = "";
            
            $item_index =  array_search('dpsc_firstname', array_column($meta["dpsc_user_info"][0], 'uname'));
            if($item_index !== FALSE ){
                $fname = $meta["dpsc_user_info"][0][$item_index]['value'];
            }
            $item_index =  array_search('dpsc_lastname', array_column($meta["dpsc_user_info"][0], 'uname'));
            if($item_index !== FALSE ){
                $lname  = $meta["dpsc_user_info"][0][$item_index]['value'];
            }
            
            $item_index =  array_search('dpsc_email', array_column($user_info, 'uname'));
            if($item_index !== FALSE ){
                $email = $meta["dpsc_user_info"][0][$item_index]['value'];
            }

            $find = array('%fname%', '%lname%', '%email%', '%inv%', '%status%', '%digi%', '%shop%');
            $replace = array($fname,$lname,$email, $order_id, $order_status, $download_content, $shop_name);
            
            $admin_mail_to = $dukapress->get_setting( 'mail->payments->admin->to' );
            $admin_mail_subject = $dukapress->get_setting( 'mail->payments->admin->subject' );
            $admin_mail_body = $dukapress->get_setting( 'mail->payments->admin->body' );
            
            $admin_mail_subject = str_replace($find, $replace, $admin_mail_subject);
            $message = str_replace($find, $replace, $admin_mail_body);

            self::send_mail($admin_mail_to, $admin_mail_subject, $message, $admin_mail_to , $shop_name); //Send admin mail
            
            
            $user_mail_from = $dukapress->get_setting( 'mail->payments->user->from' );
            $user_mail_subject = $dukapress->get_setting( 'mail->payments->user->subject' );
            $user_mail_body = $dukapress->get_setting( 'mail->payments->user->body' );
            
            $user_mail_subject = str_replace($find, $replace, $user_mail_subject);
            $message = str_replace($find, $replace, $user_mail_body);
            
            self::send_mail($email,  $user_mail_subject, $message, $user_mail_from , $shop_name); //Send user mail
        }
        
    }

    /**
     * Send Mail
     * @param String $to - Person to recieve the mail
     * @param String $subject - Mail Subject
     * @param String $msg - Mail content
     * @param String $from - Person who sent the mail. Default to WordPress admin
     * @param String $name - NAme of person who sent the mail. Defaults to site title
     * @param String $attachment - Full path to attachment
     */
    static function send_mail($to,  $subject, $msg, $from = FALSE , $name = FALSE, $attachment = FALSE){
        if(!$from){
            $from = get_option( "admin_email" );
        }
        if(!$name){
            $name = get_bloginfo('name');
        }
        $headers  = 'MIME-Version: 1.0' . "\r\n";
        $headers .= 'Content-type: text/html; charset=utf-8' . "\r\n";
        if($from)
            $headers .= 'From: ' . $name . ' <' . $from . '>' . "\r\n";
        if ($attachment) {
          @wp_mail($to, $subject, $msg, $headers,$attachment);
        }
        else {
          @wp_mail($to, $subject, $msg, $headers);
        }
    }
  }
}
?>
