<?php
class Dpsc_2Checkout extends DukaPress_Gateway{
    
    var $currencies, $accountNumber, $accountSecret, $returnURL, $paymentURL, $currencyCode;
    
    function on_create(){
		global $dukapress;
		$this->plugin_name = __('2Checkout','dp-lang');
		$this->plugin_slug = '2checkout';
		$this->currencies = $dukapress->tc0_supported_currency;
        
        $this->plugin_public_name = $dukapress->get_setting('gateways->2checkout->public');
        if(empty($this->plugin_public_name)){
            $this->plugin_public_name = $this->plugin_name;
        }
		$this->accountNumber = $dukapress->get_setting('gateways->2checkout->accountNumber');
        $this->accountSecret = $dukapress->get_setting('gateways->2checkout->accountSecret');
		
        $this->currencyCode = $dukapress->get_setting('gateways->2checkout->currency');
        
        if ( $dukapress->get_setting('gateways->2checkout->mode') == 'sandbox' )	{
            $this->paymentURL = "https://sandbox.2checkout.com/checkout/purchase";
        } else {
            $this->paymentURL = "https://www.2checkout.com/checkout/purchase";
        }
        
        $this->form_submit = true;
	}
    
    
    function set_up_options($settings){
		?>
		<h3 class='hndle'><span><?php _e('2Checkout Settings','dp-lang'); ?></span></h3>
		<table class="form-table">
            <tr>
                <th scope="row"><?php _e('Public Name','dp-lang'); ?></th>
                <td>
                    <input value="<?php echo @$settings['gateways']['2checkout']['public']; ?>"  name="dpsc[gateways][2checkout][public]" type="text" />
                </td>
            </tr>
            <tr>
                <th scope="row"><?php _e('2Checkout Mode','dp-lang'); ?></th>
                <td>
                    <select name="dpsc[gateways][2checkout][mode]">
                        <option value="sandbox" <?php selected($settings['gateways']['2checkout']['mode'], 'sandbox'); ?>><?php _e('Sandbox','dp-lang'); ?></option>
                        <option value="live" <?php selected($settings['gateways']['2checkout']['mode'], 'live'); ?>><?php _e('Live','dp-lang'); ?></option>
                    </select>
                </td>
            </tr>
            <tr>
                <th scope="row"><?php _e('2Checkout Account Number','dp-lang'); ?></th>
                <td>
                    <input value="<?php echo @$settings['gateways']['2checkout']['accountNumber']; ?>"  name="dpsc[gateways][2checkout][accountNumber]" type="text" />
                </td>
            </tr>
            <tr>
                <th scope="row"><?php _e('2Checkout Secret Word','dp-lang'); ?></th>
                <td>
                    <input value="<?php echo @$settings['gateways']['2checkout']['accountSecret']; ?>"  name="dpsc[gateways][2checkout][accountSecret]" type="text" />
                </td>
            </tr>
            <tr>
                <th scope="row"><?php _e('2Checkout Currency','dp-lang') ?></th>
                <td>
                    <select name="dpsc[gateways][2checkout][currency]">
                        <?php
                        $sel_currency = $settings['gateways']['2checkout']['currency'];
                        foreach ($this->currencies as $k => $v) {
                            echo '<option value="' . $k . '"' . ($k == $sel_currency ? ' selected' : '') . '>' . esc_html($v, true) . '</option>' . "\n";
                        }
                        ?>
                    </select>
                </td>
            </tr>
		</table>
		
		<?php
	}
    
    
    function process_payment_form($cart, $user_info, $shipping, $order_id,$total_shipping, $total_discount, $total_tax,$dpsc_total, $return_path){
        global $dukapress;
        $conversion_rate = 1;
        if ($this->currencyCode != $dukapress->get_setting('shop_currency')) {
            $conversion_rate = dukapress_shop_currency_conversion_rate($this->currencyCode);
        }
        $timestamp = time();
        if ( $dukapress->get_setting('gateways->2checkout->mode') == 'sandbox' ){
            $params['demo'] = 'Y';
        } 
        $params['sid'] = $this->accountNumber;
        $params['cart_order_id'] = $order_id;
        $params['x_receipt_link_url'] = $return_path;
        $params['skip_landing'] = '1';
        $params['fixed'] = 'Y';
        $params['currency_code'] = $this->currencyCode;
        $params['mode'] = '2CO';
        
        $totals = array();
        $counter = 1;

        $params["id_type"] = 1;
        
        foreach ($cart as $key => $dpsc_product) {
            $price = $dpsc_product['price'];
			$price = apply_filters('dukapress_gateway_item_price',$price,$dpsc_product);
            
            $totals[] = ($price * $dpsc_product['quantity']);
            
            $prefix = 'li_' . $counter;
            
            $sku = empty( $dpsc_product['sku'] ) ? $dpsc_product['item_number'] : $dpsc_product['sku'];
            $params["{$prefix}_product_id"] = $sku;
            $params["{$prefix}_name"] = $dpsc_product['name'];
            $params["{$prefix}_quantity"] = $dpsc_product['quantity'];
            $params["{$prefix}_description"] = get_permalink($dpsc_product['item_number']);
            $params["{$prefix}_price"] = $conversion_rate * $price;
            $params["{$prefix}_type"] = 'product';
            $counter ++;
        }
        if ($total_shipping > 0) {
            $prefix = 'li_' . $counter;
		    $params["{$prefix}_product_id"] = 'shipping';
		    $params["{$prefix}_name"] = 'Shipping';
        	$params["{$prefix}_type"] = 'shipping';
            $params["{$prefix}_price"] = $conversion_rate * $total_shipping;
            
            $counter += 1;
			$totals[] = $shipping_price;
        }
        
        if ($total_tax > 0) {
            $prefix = 'li_' . $counter;
	        $params["{$prefix}_product_id"] = 'taxes';
	        $params["{$prefix}_name"] = 'Taxes';
        	$params["{$prefix}_type"] = 'tax';
        	$params["{$prefix}_price"] = $total_tax;

        	$counter += 1;
        	$totals[] = $tax_price;
        }
        
        $params['total'] = array_sum( $totals );
        
        $url = $this->paymentURL . '?' . http_build_query( $params );
        
        $output = '<form name="dpsc_paypal_form" id="dpsc_payment_form" action="' . $url . '" method="get">';
        $output .= '</form>';
        $this->send_gateway_output($output);
    }
    
    //Call back
    function update_payment($request){
        $updated_status = 'received';
        if (isset($request['message_type']) && $request['message_type'] == 'INVOICE_STATUS_CHANGED') {
            global $dukapress;
            $sale_id = $request['sale_id'];
            $tco_invoice_id = $request['invoice_id'];
            $tco_vendor_order_id = $request['vendor_order_id'];
            $tco_invoice_status = $request['invoice_status'];
            $tco_hash = $request['md5_hash'];
            $total = $request['invoice_list_amount'];
            $payment_method = ucfirst($request['payment_type']);
            
            $accountNumber = $dukapress->get_setting('gateways->2checkout->accountNumber');
            $accountSecret = $dukapress->get_setting('gateways->2checkout->accountSecret');
            
            $calc_key = md5($sale_id . $accountNumber . $tco_invoice_id .  $accountSecret);
            
            if (strtolower($tco_hash) != strtolower($calc_key)) {
                $updated_status = 'cancelled';
            }
            if (strtolower($tco_invoice_status) != "deposited") {
                $updated_status = 'cancelled';
            }
            if ( $dukapress->get_setting('gateways->2checkout->mode') != 'sandbox' ){
                $updated_status = 'paid';
            }else{
                $updated_status = 'paid';
            }
        }
        return $updated_status;
    }
}
?>