<?php
class Dpsc_PayPal extends DukaPress_Gateway{

	//paypal vars
    var $currencies, $email, $returnURL, $cancelURL, $paypalURL, $currencyCode;
    
	function on_create(){
		global $dukapress;
		$this->plugin_name = __('PayPal Standard','dp-lang');
		$this->plugin_slug = 'paypal';
		$this->currencies = $dukapress->paypal_supported_currency;
        
        $this->plugin_public_name = $dukapress->get_setting('gateways->paypal->public');
        if(empty($this->plugin_public_name)){
            $this->plugin_public_name = $this->plugin_name;
        }
		$this->email = $dukapress->get_setting('gateways->paypal->id');
		
        $this->currencyCode = $dukapress->get_setting('gateways->paypal->currency');


		//set api urls
        if ( $dukapress->get_setting('gateways->paypal->mode') == 'sandbox' )	{
            $this->paypalURL = "https://www.sandbox.paypal.com/cgi-bin/webscr";
        } else {
            $this->paypalURL = "https://www.paypal.com/cgi-bin/webscr";
        }
        $this->form_submit = true;
	}


	function set_up_options($settings){
		?>
		<h3 class='hndle'><span><?php _e('PayPal Standard Checkout Settings','dp-lang'); ?></span></h3>
		<table class="form-table">
            <tr>
                <th scope="row"><?php _e('Public Name','dp-lang'); ?></th>
                <td>
                    <input value="<?php echo @$settings['gateways']['paypal']['public']; ?>"  name="dpsc[gateways][paypal][public]" type="text" />
                </td>
            </tr>
            <tr>
                <th scope="row"><?php _e('PayPal Mode','dp-lang'); ?></th>
                <td>
                    <select name="dpsc[gateways][paypal][mode]">
                        <option value="sandbox" <?php selected($settings['gateways']['paypal']['mode'], 'sandbox'); ?>><?php _e('Sandbox','dp-lang'); ?></option>
                        <option value="live" <?php selected($settings['gateways']['paypal']['mode'], 'live'); ?>><?php _e('Live','dp-lang'); ?></option>
                    </select>
                </td>
            </tr>
            <tr>
                <th scope="row"><?php _e('PayPal Currency','dp-lang') ?></th>
                <td>
                    <select name="dpsc[gateways][paypal][currency]">
                        <?php
                        $sel_currency = $settings['gateways']['paypal']['currency'];
                        foreach ($this->currencies as $k => $v) {
                            echo '<option value="' . $k . '"' . ($k == $sel_currency ? ' selected' : '') . '>' . esc_html($v, true) . '</option>' . "\n";
                        }
                        ?>
                    </select>
                </td>
            </tr>
            <tr>
                <th scope="row"><?php _e('PayPal Merchant E-mail','dp-lang'); ?></th>
                <td>
                    <input value="<?php echo @$settings['gateways']['paypal']['id']; ?>"  name="dpsc[gateways][paypal][id]" type="text" />
                </td>
            </tr>
		</table>
		
		<?php
	}

	function process_payment_form($cart, $user_info, $shipping, $order_id,$total_shipping, $total_discount, $total_tax,$dpsc_total, $return_path){
        global $dukapress;
        $conversion_rate = 1;
        if ($this->currencyCode != $dukapress->get_setting('shop_currency')) {
            $conversion_rate = dukapress_shop_currency_conversion_rate($this->currencyCode);
        }
        $output = '<form name="dpsc_paypal_form" id="dpsc_payment_form" action="' . $this->paypalURL . '" method="post">';
        $output .= '<input type="hidden" name="return" value="' . $return_path . '"/>
                     <input type="hidden" name="cmd" value="_ext-enter" />
                     <input type="hidden" name="notify_url" value="' . $this->ipn_url . '"/>
                     <input type="hidden" name="redirect_cmd" value="_cart" />
                     <input type="hidden" name="business" value="' . $this->email . '"/>
                     <input type="hidden" name="cancel_return" value="' . $return_path . '&status=cancel"/>
                     <input type="hidden" name="rm" value="2" />
                     <input type="hidden" name="upload" value="1" />
                     <input type="hidden" name="currency_code" value="' . $this->currencyCode . '"/>
                     <input type="hidden" name="no_note" value="1" />
                     <input type="hidden" name="invoice" value="' . $order_id . '">';
        
        $output .= '<input type="hidden" name="first_name" value="' . dukapress_checkout_setting_value($user_info, "dpsc_firstname") . '"/>';
        $output .= '<input type="hidden" name="last_name" value="' . dukapress_checkout_setting_value($user_info, "dpsc_lastname") . '"/>';
        $output .= '<input type="hidden" name="address1" value="' . dukapress_checkout_setting_value($user_info, "dpsc_address") . '"/>';
        $output .= '<input type="hidden" name="state" value="' . dukapress_checkout_setting_value($user_info, "dpsc_state") . '"/>';
        $output .= '<input type="hidden" name="country" value="' . dukapress_checkout_setting_value($user_info, "dpsc_country") . '"/>';
        $output .= '<input type="hidden" name="email" value="' . dukapress_checkout_setting_value($user_info, "dpsc_email") . '"/>';
        
        $dpsc_count_product = 1;
        $tax_rate = 0;
        $dpsc_shipping_total = 0.00;
        if ($dukapress->get_setting('tax->rate') > 0) {
            $tax_rate = $dukapress->get_setting('tax->rate');
        }
		
        foreach ($cart as $key => $dpsc_product) {
            $dpsc_var = '';
            $var_paypal_field = '';
            if (!empty($dpsc_product['var'])) {
                $dpsc_var = ' (' . $dpsc_product['var'] . ')';
                $var_paypal_field = '<input type="hidden" name="on0_' . $dpsc_count_product . '" value="Variation Selected" />
                                     <input type="hidden" name="os0_' . $dpsc_count_product . '" value="' . $dpsc_var . '"  />';
            }
			$paypal_price = $dpsc_product['price'];
			$paypal_price = apply_filters('dukapress_gateway_item_price',$paypal_price,$dpsc_product);
            $output .= '<input type="hidden" name="item_name_' . $dpsc_count_product . '" value="' . $dpsc_product['name'] . $dpsc_var . '"/>
                             <input type="hidden" name="amount_' . $dpsc_count_product . '" value="' . number_format($conversion_rate * $paypal_price, 2) . '"/>
                             <input type="hidden" name="quantity_' . $dpsc_count_product . '" value="' . $dpsc_product['quantity'] . '"/>
                             <input type="hidden" name="item_number_' . $dpsc_count_product . '" value="' . $dpsc_product['item_number'] . '"/>
                             <input type="hidden" name="tax_rate_' . $dpsc_count_product . '" value="' . $tax_rate . '"/>'
                    . $var_paypal_field;
            if ($dukapress->get_setting('discount') && $total_discount) {
                $output .= '<input type="hidden" name="discount_rate_' . $dpsc_count_product . '" value="' . $total_discount . '">';
            }
            $dpsc_count_product++;
        }
        if ($total_shipping > 0) {
            $total_shipping = $conversion_rate * $total_shipping;
        }
        $output .= '<input type="hidden" name="handling_cart" value="' . number_format($total_shipping, 2) . '"/></form>';
        $this->send_gateway_output($output);
	}

	function update_payment($request){
        global $dukapress;
		$req = 'cmd=_notify-validate';
        foreach ($_POST as $key => $value) {
            $value = urlencode(stripslashes($value));
            $req .= "&$key=$value";
        }
        $dpsc_form_action = $this->paypalURL;
        $ch = curl_init($dpsc_form_action);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, FALSE);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($ch, CURLOPT_POST, 1);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $req);
        $result = curl_exec($ch);
        curl_close($ch);
        if (strcmp($result, "VERIFIED") == 0) {
            $invoice = $_POST['invoice'];
            $tx_id = $_POST['txn_id'];
            $payer_email = $_POST['payer_email'];
            $payment_status = $_POST['payment_status'];
            switch ($payment_status) {
                case 'Processed':
                    $updated_status = 'paid';
                    break;
                case 'Completed':
                    $updated_status = 'paid';
                    break;
                case 'Pending':
                    $updated_status = 'received';
                    break;
                default:
                    $updated_status = 'cancelled';
                    break;
            }
            return $updated_status;
        }else{
            return 'received';
        }
	}
    
    function process_ipn_return(){
        global $dukapress;
		$req = 'cmd=_notify-validate';
        foreach ($_POST as $key => $value) {
            $value = urlencode(stripslashes($value));
            $req .= "&$key=$value";
        }
        if ( $dukapress->get_setting('gateways->paypal->mode') == 'sandbox' )	{
            $dpsc_form_action = "https://www.sandbox.paypal.com/cgi-bin/webscr";
        } else {
            $dpsc_form_action = "https://www.paypal.com/cgi-bin/webscr";
        }
        $ch = curl_init($dpsc_form_action);
        curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, FALSE);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($ch, CURLOPT_POST, 1);
        curl_setopt($ch, CURLOPT_POSTFIELDS, $req);
        $result = curl_exec($ch);
        curl_close($ch);
        if (strcmp($result, "VERIFIED") == 0) {
            $invoice = $_POST['invoice'];
            $tx_id = $_POST['txn_id'];
            $payer_email = $_POST['payer_email'];
            $payment_status = $_POST['payment_status'];
            switch ($payment_status) {
                case 'Processed':
                    $updated_status = 'paid';
                    break;
                case 'Completed':
                    $updated_status = 'paid';
                    break;
                case 'Pending':
                    $updated_status = 'received';
                    break;
                default:
                    $updated_status = 'cancelled';
                    break;
            }
            $dukapress->update_order_status($invoice, $updated_status);
            if($updated_status === 'paid'){
                DukaPress_Mail::payment_mail($invoice);
            }
        }
    }
    

}
?>
