<?php
class Dpsc_PesaPal extends DukaPress_Gateway{
    
    //pesapal vars
    var $currencies, $customer_key, $customer_secret, $returnURL, $postUrl, $paymentQueryURL, $currencyCode;
    
    function on_create(){
		global $dukapress;
		$this->plugin_name = __('PesaPal','dp-lang');
		$this->plugin_slug = 'pesapal';
		$this->currencies = $dukapress->pesapal_supported_currency;
        
        $this->plugin_public_name = $dukapress->get_setting('gateways->pesapal->public');
        if(empty($this->plugin_public_name)){
            $this->plugin_public_name = $this->plugin_name;
        }
		$this->customer_key = $dukapress->get_setting('gateways->pesapal->customer_key');
        $this->customer_secret = $dukapress->get_setting('gateways->pesapal->customer_secret');
		
        $this->currencyCode = $dukapress->get_setting('gateways->pesapal->currency');


		//set api urls
        if ( $dukapress->get_setting('gateways->pesapal->mode') == 'sandbox' )	{
            $this->postUrl = "http://demo.pesapal.com/api/PostPesapalDirectOrderV4";
            $this->paymentQueryURL = "https://demo.pesapal.com/api/querypaymentstatus";
        } else {
            $this->postUrl = "https://www.pesapal.com/api/PostPesapalDirectOrderV4";
            $this->paymentQueryURL = "https://www.pesapal.com/api/querypaymentstatus";
        }
        $this->form_submit = false;
	}
    
    function set_up_options($settings){
		?>
		<h3 class='hndle'><span><?php _e('PesaPal Settings','dp-lang'); ?></span></h3>
		<table class="form-table">
            <tr>
                <td colspan="2">
                    <p>
                        <?php _e('PesaPal requires Full names and email/phone number. To handle IPN return requests, please set the url '); ?>
                        <strong><?php echo $this->ipn_url; ?></strong>
                        <?php _e(' on your <a href="https://www.pesapal.com/merchantdashboard" target="_blank">pesapal</a> account settings'); ?>
                    </p>
                </td>
            </tr>
            <tr>
                <th scope="row"><?php _e('Public Name','dp-lang'); ?></th>
                <td>
                    <input value="<?php echo @$settings['gateways']['pesapal']['public']; ?>"  name="dpsc[gateways][pesapal][public]" type="text" />
                </td>
            </tr>
            <tr>
                <th scope="row"><?php _e('PesaPal Mode','dp-lang'); ?></th>
                <td>
                    <select name="dpsc[gateways][pesapal][mode]">
                        <option value="sandbox" <?php selected($settings['gateways']['pesapal']['mode'], 'sandbox'); ?>><?php _e('Sandbox','dp-lang'); ?></option>
                        <option value="live" <?php selected($settings['gateways']['pesapal']['mode'], 'live'); ?>><?php _e('Live','dp-lang'); ?></option>
                    </select>
                </td>
            </tr>
            <tr>
                <th scope="row"><?php _e('PesaPal Currency','dp-lang') ?></th>
                <td>
                    <select name="dpsc[gateways][pesapal][currency]">
                        <?php
                        $sel_currency = @$settings['gateways']['pesapal']['currency'];
                        foreach ($this->currencies as $k => $v) {
                            echo '<option value="' . $k . '"' . ($k == $sel_currency ? ' selected' : '') . '>' . esc_html($v, true) . '</option>' . "\n";
                        }
                        ?>
                    </select>
                </td>
            </tr>
            <tr>
                <th scope="row"><?php _e('PesaPal Merchant Customer Key','dp-lang'); ?></th>
                <td>
                    <input value="<?php echo @$settings['gateways']['pesapal']['customer_key']; ?>"  name="dpsc[gateways][pesapal][customer_key]" type="text" />
                </td>
            </tr>
            <tr>
                <th scope="row"><?php _e('PesaPal Merchant Customer Secret','dp-lang'); ?></th>
                <td>
                    <input value="<?php echo @$settings['gateways']['pesapal']['customer_secret']; ?>"  name="dpsc[gateways][pesapal][customer_secret]" type="text" />
                </td>
            </tr>
		</table>
		
		<?php
	}
    
    function process_payment_form($cart, $user_info, $shipping, $order_id,$total_shipping, $total_discount, $total_tax,$dpsc_total, $return_path){
        require_once(DPSC_DUKAPRESS_GATEWAY_DIR.'/libraries/pesapal/OAuth.php');
        global $dukapress;
        $conversion_rate = 1;
        if ($this->currencyCode != $dukapress->get_setting('shop_currency')) {
            $conversion_rate = dukapress_shop_currency_conversion_rate($this->currencyCode);
        }
        
        $firstname = dukapress_checkout_setting_value($user_info, "dpsc_firstname");
		$lastname = dukapress_checkout_setting_value($user_info, "dpsc_lastname");
        
        $token = $params = NULL;
		$signature_method = new PesaPalOAuthSignatureMethod_HMAC_SHA1();
        
        $firstname = dukapress_checkout_setting_value($user_info, "dpsc_firstname");
        $lastname = dukapress_checkout_setting_value($user_info, "dpsc_lastname");
            
        $desc = 'Your Order No.: '.$order_id;
		$type = 'MERCHANT';
		$reference = $order_id;
		$first_name = $firstname;
		$fullnames = $firstname.' '.$lastname;
		$last_name = $lastname;
		$email = dukapress_checkout_setting_value($user_info, "dpsc_email");
		$username = $email; //same as email
		$phonenumber = '';//leave blank
		$payment_method = '';//leave blank
		$code = '';//leave blank
		$currency = $this->currencyCode;
        
        $post_xml = "<?xml version=\"1.0\" encoding=\"utf-8\"?><PesapalDirectOrderInfo xmlns:xsi=\"http://www.w3.org/2001/XMLSchemainstance\" xmlns:xsd=\"http://www.w3.org/2001/XMLSchema\" Amount=\"".($dpsc_total * $conversion_rate)."\" Description=\"".$desc."\" Code=\"".$code."\" Currency=\"".$currency."\" Type=\"".$type."\" PaymentMethod=\"".$payment_method."\" Reference=\"".$reference."\" FirstName=\"".$first_name."\" LastName=\"".$last_name."\" Email=\"".$email."\" PhoneNumber=\"".$phonenumber."\" UserName=\"".$username."\" xmlns=\"http://www.pesapal.com\" />";
		$post_xml = htmlentities($post_xml);
        
        $consumer = new PesaPalOAuthConsumer($this->customer_key, $this->consumer_secret);
        
        $iframe_src = PesaPalOAuthRequest::from_consumer_and_token($consumer, $token, "GET", $this->postUrl, $params);
		$iframe_src->set_parameter("oauth_callback", $return_path);
		$iframe_src->set_parameter("pesapal_request_data", $post_xml);
		$iframe_src->sign_request($signature_method, $consumer, $token);
        
        $output = '<iframe src="'.$iframe_src.'" width="100%" height="100%" style="overflow:hidden;overflow-x:hidden;overflow-y:hidden;height:100%;width:100%;position:absolute;top:0px;left:0px;right:0px;bottom:0px" scrolling="no" frameBorder="0" >';
		$output .= '</iframe>';
        $this->send_gateway_output($output);
    }
    
    function update_payment($request){
        $updated_status = 'received';
        require_once(DPSC_DUKAPRESS_GATEWAY_DIR.'/libraries/pesapal/OAuth.php');
        global $dukapress;
        
        $consumer_key = $dukapress->get_setting('gateways->pesapal->customer_key');
		$consumer_secret = $dukapress->get_setting('gateways->pesapal->consumer_secret');
		
		$transaction_tracking_id = $request['pesapal_transaction_tracking_id'];
		$payment_notification = $request['pesapal_notification_type'];
		$invoice = $request['pesapal_merchant_reference'];
        
        if ( $dukapress->get_setting('gateways->pesapal->mode') == 'sandbox' )	{
            $paymentQueryURL = "https://demo.pesapal.com/api/querypaymentstatus";
        } else {
            $paymentQueryURL = "https://www.pesapal.com/api/querypaymentstatus";
        }
        
        if(!empty($transaction_tracking_id)){
            $token = $params = NULL;
			$consumer = new PesaPalOAuthConsumer($consumer_key, $consumer_secret);
			$signature_method = new OAuthSignatureMethod_HMAC_SHA1();

			//get transaction status
			$request_status = PesaPalOAuthRequest::from_consumer_and_token($consumer, $token, "GET", $paymentQueryURL, $params);
			$request_status->set_parameter("pesapal_merchant_reference", $pesapal_merchant_reference);
			$request_status->set_parameter("pesapal_transaction_tracking_id",$invoice);
			$request_status->sign_request($signature_method, $consumer, $token);
			$ch = curl_init();
			curl_setopt($ch, CURLOPT_URL, $request_status);
			curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
			curl_setopt($ch, CURLOPT_HEADER, 1);
			curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 0);
			 if(defined('CURL_PROXY_REQUIRED')) if (CURL_PROXY_REQUIRED == 'True'){
				$proxy_tunnel_flag = (defined('CURL_PROXY_TUNNEL_FLAG') && strtoupper(CURL_PROXY_TUNNEL_FLAG) == 'FALSE') ? false : true;
				curl_setopt ($ch, CURLOPT_HTTPPROXYTUNNEL, $proxy_tunnel_flag);
				curl_setopt ($ch, CURLOPT_PROXYTYPE, CURLPROXY_HTTP);
				curl_setopt ($ch, CURLOPT_PROXY, CURL_PROXY_SERVER_DETAILS);
			}

			$response = curl_exec($ch);

			$header_size = curl_getinfo($ch, CURLINFO_HEADER_SIZE);
			$raw_header  = substr($response, 0, $header_size - 4);
			$headerArray = explode("\r\n\r\n", $raw_header);
			$header      = $headerArray[count($headerArray) - 1];

			 //transaction status
			$elements = preg_split("/=/",substr($response, $header_size));
			$status = $elements[1];

			curl_close ($ch);
            
            switch ($status) {
				case 'PENDING':
					$updated_status = 'received';
					break;
				case 'COMPLETED':
					$updated_status = 'paid';
					break;
				case 'FAILED':
					$updated_status = 'cancelled';
					break;
				default:
					$updated_status = 'cancelled';
					break;
			}
        }
        return $updated_status;
    }
    
    
    function process_ipn_return(){
        require_once(DPSC_DUKAPRESS_GATEWAY_DIR.'/libraries/pesapal/OAuth.php');
        global $dukapress;
        
        $consumer_key = $dukapress->get_setting('gateways->pesapal->customer_key');
		$consumer_secret = $dukapress->get_setting('gateways->pesapal->consumer_secret');
		
		$transaction_tracking_id = $_REQUEST['pesapal_transaction_tracking_id'];
		$payment_notification = $_REQUEST['pesapal_notification_type'];
		$invoice = $_REQUEST['pesapal_merchant_reference'];
        
        if ( $dukapress->get_setting('gateways->pesapal->mode') == 'sandbox' )	{
            $paymentQueryURL = "https://demo.pesapal.com/api/querypaymentstatus";
        } else {
            $paymentQueryURL = "https://www.pesapal.com/api/querypaymentstatus";
        }
        
        if(!empty($transaction_tracking_id)){
            $token = $params = NULL;
			$consumer = new PesaPalOAuthConsumer($consumer_key, $consumer_secret);
			$signature_method = new OAuthSignatureMethod_HMAC_SHA1();

			//get transaction status
			$request_status = PesaPalOAuthRequest::from_consumer_and_token($consumer, $token, "GET", $paymentQueryURL, $params);
			$request_status->set_parameter("pesapal_merchant_reference", $pesapal_merchant_reference);
			$request_status->set_parameter("pesapal_transaction_tracking_id",$invoice);
			$request_status->sign_request($signature_method, $consumer, $token);
			$ch = curl_init();
			curl_setopt($ch, CURLOPT_URL, $request_status);
			curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
			curl_setopt($ch, CURLOPT_HEADER, 1);
			curl_setopt($ch, CURLOPT_SSL_VERIFYPEER, 0);
			 if(defined('CURL_PROXY_REQUIRED')) if (CURL_PROXY_REQUIRED == 'True'){
				$proxy_tunnel_flag = (defined('CURL_PROXY_TUNNEL_FLAG') && strtoupper(CURL_PROXY_TUNNEL_FLAG) == 'FALSE') ? false : true;
				curl_setopt ($ch, CURLOPT_HTTPPROXYTUNNEL, $proxy_tunnel_flag);
				curl_setopt ($ch, CURLOPT_PROXYTYPE, CURLPROXY_HTTP);
				curl_setopt ($ch, CURLOPT_PROXY, CURL_PROXY_SERVER_DETAILS);
			}

			$response = curl_exec($ch);

			$header_size = curl_getinfo($ch, CURLINFO_HEADER_SIZE);
			$raw_header  = substr($response, 0, $header_size - 4);
			$headerArray = explode("\r\n\r\n", $raw_header);
			$header      = $headerArray[count($headerArray) - 1];

			 //transaction status
			$elements = preg_split("/=/",substr($response, $header_size));
			$status = $elements[1];

			curl_close ($ch);
            
            switch ($status) {
				case 'PENDING':
					$updated_status = 'received';
					break;
				case 'COMPLETED':
					$updated_status = 'paid';
					break;
				case 'FAILED':
					$updated_status = 'cancelled';
					break;
				default:
					$updated_status = 'cancelled';
					break;
			}
            $dukapress->update_order_status($invoice, $updated_status);
            if($updated_status === 'paid'){
                DukaPress_Mail::payment_mail($invoice);
            }
        }
        $resp="pesapal_notification_type=$payment_notification&pesapal_transaction_tracking_id=$transaction_tracking_id&pesapal_merchant_reference=$invoice";
		ob_start();
		echo $resp;
		ob_flush();
		exit();
    }
    
    
}
?>