<?php
class Dpsc_WorldPay extends DukaPress_Gateway{
    
    var $currencies, $id, $returnURL, $cancelURL, $postURL, $currencyCode, $testModeVal;
    
    function on_create(){
		global $dukapress;
		$this->plugin_name = __('WorldPay','dp-lang');
		$this->plugin_slug = 'worldpay';
		$this->currencies = $dukapress->worldpay_supported_currency;
        
        $this->plugin_public_name = $dukapress->get_setting('gateways->worldpay->public');
        if(empty($this->plugin_public_name)){
            $this->plugin_public_name = $this->plugin_name;
        }
		$this->id = $dukapress->get_setting('gateways->worldpay->id');
		
        $this->currencyCode = $dukapress->get_setting('gateways->worldpay->currency');


		//set api urls
        if ( $dukapress->get_setting('gateways->worldpay->mode') == 'sandbox' )	{
            $this->postURL = "https://secure-test.worldpay.com/wcc/purchase";
            $this->testModeVal = '100';
        } else {
            $this->postURL = "https://secure.worldpay.com/wcc/purchase";
            $this->testModeVal = '0';
        }
        $this->form_submit = true;
	}
    
    function set_up_options($settings){
		?>
		<h3 class='hndle'><span><?php _e('WorldPay Settings','dp-lang'); ?></span></h3>
		<table class="form-table">
            <tr>
                <th scope="row"><?php _e('Public Name','dp-lang'); ?></th>
                <td>
                    <input value="<?php echo @$settings['gateways']['worldpay']['public']; ?>"  name="dpsc[gateways][worldpay][public]" type="text" />
                </td>
            </tr>
            <tr>
                <th scope="row"><?php _e('WorldPay Mode','dp-lang'); ?></th>
                <td>
                    <select name="dpsc[gateways][worldpay][mode]">
                        <option value="sandbox" <?php selected($settings['gateways']['worldpay']['mode'], 'sandbox'); ?>><?php _e('Sandbox','dp-lang'); ?></option>
                        <option value="live" <?php selected($settings['gateways']['worldpay']['mode'], 'live'); ?>><?php _e('Live','dp-lang'); ?></option>
                    </select>
                </td>
            </tr>
            <tr>
                <th scope="row"><?php _e('WorldPay Currency','dp-lang') ?></th>
                <td>
                    <select name="dpsc[gateways][worldpay][currency]">
                        <?php
                        $sel_currency = $settings['gateways']['worldpay']['currency'];
                        foreach ($this->currencies as $k => $v) {
                            echo '<option value="' . $k . '"' . ($k == $sel_currency ? ' selected' : '') . '>' . esc_html($v, true) . '</option>' . "\n";
                        }
                        ?>
                    </select>
                </td>
            </tr>
            <tr>
                <th scope="row"><?php _e('WorldPay ID','dp-lang'); ?></th>
                <td>
                    <input value="<?php echo @$settings['gateways']['worldpay']['id']; ?>"  name="dpsc[gateways][worldpay][id]" type="text" />
                </td>
            </tr>
		</table>
		
		<?php
	}
    
    function process_payment_form($cart, $user_info, $shipping, $order_id,$total_shipping, $total_discount, $total_tax,$dpsc_total, $return_path){
        global $dukapress;
        $conversion_rate = 1;
        if ($this->currencyCode != $dukapress->get_setting('shop_currency')) {
            $conversion_rate = dukapress_shop_currency_conversion_rate($this->currencyCode);
        }
        if ( $dukapress->get_setting('gateways->worldpay->mode') == 'sandbox' )	{
            $name = 'AUTHORISED';
        } else {
           $name = dukapress_checkout_setting_value($user_info, "dpsc_firstname").' '.dukapress_checkout_setting_value($user_info, "dpsc_lastname");
        }
        $total_amount = ($dpsc_total + $total_tax + $total_shipping - $total_discount) * $conversion_rate;
        $dpsc_total = number_format($total_amount, 2, '.', '');
        $lang = (strlen(WPLANG) > 0 ? substr(WPLANG, 0, 2) : 'en');
        $output = '<form name="dpsc_worldpay_form" id="dpsc_payment_form" action="' . $this->postURL . '" method="post">
                        <input type="hidden" name="instId" value="' . $this->id . '" />
                        <input type="hidden" name="currency" value="' . $this->currencyCode . '" />
                        <input type="hidden" name="desc" value="Your Order No.: ' . $order_id . '" />
                        <input type="hidden" name="cartId" value="101KT0098" />
                        <input type="hidden" name="amount" value="' . $dpsc_total . '" />
                        <input type="hidden" name="testMode" value="' . $this->testModeVal . '" />
                        <input type="hidden" name="name" value="' . $name . '" />
                        <input type="hidden" name="address" value="' . dukapress_checkout_setting_value($user_info, "dpsc_address") . ' ' . dukapress_checkout_setting_value($user_info, "dpsc_state") . '" />
                        <input type="hidden" name="country" value="' . dukapress_checkout_setting_value($user_info, "dpsc_country") . '" />
                        <input type="hidden" name="tel" value="" />
                        <input type="hidden" name="email" value="' . dukapress_checkout_setting_value($user_info, "dpsc_email") . '" />
                        <input type="hidden" name="lang" value="' . $lang . '" />
                        <input type="hidden" name="MC_invoice" value="' . $order_id . '" />
                        <input type="hidden" name="MC_callback" value="' . $return_path . '" />
                    </form>';
        
        $this->send_gateway_output($output);
        
    }
}
?>