<?php
class Dukapress_PostMeta{

    static function init(){
        add_action('add_meta_boxes_duka', array(__CLASS__, 'meta_boxes'));
        add_action('wp_insert_post', array(__CLASS__, 'save_product_meta'), 10, 2);
        add_filter('enter_title_here', array(__CLASS__, 'filter_title'));

        //Ajax Actions
        add_action('wp_ajax_save_variationdata', array(__CLASS__, 'varition_save_data'));
        add_action('wp_ajax_delete_variationdata', array(__CLASS__, 'varition_delete_data'));
        add_action('wp_ajax_delete_variationdata_option', array(__CLASS__, 'vaiation_delete_data_option'));
        add_action('wp_ajax_update_variationdata_option', array(__CLASS__, 'vaiation_update_data_option'));
        
        add_action('wp_ajax_dpsc_order_status', array(__CLASS__, 'change_order_status'));
        
        //Order Meta Boxes
        add_action('add_meta_boxes_duka_order', array(__CLASS__, 'order_meta_boxes'));
    }

    /**
    * Filter Title on Edit Product page
    */
    static function filter_title($post) {
        global $post_type;

        if ($post_type != 'duka') return $post;

        return __('Enter Product title here', 'dp-lang');
    }

    /**
    * Add Meta Box
    *
    */
    static function meta_boxes() {
        global $wp_meta_boxes;
        add_meta_box('duka-meta-details', __('Product Details', 'dp-lang'), array(__CLASS__, 'meta_details'), 'duka', 'normal', 'high');
        add_meta_box('duka-variation-meta-details', __('Product Variations', 'dp-lang'), array(__CLASS__, 'variation_meta_details'), 'duka', 'normal', 'high');
        
        if (isset($wp_meta_boxes['duka']['side']['low']['postimagediv'])) {
            $imagediv = $wp_meta_boxes['duka']['side']['low']['postimagediv'];
            unset($wp_meta_boxes['duka']['side']['low']['postimagediv']);
            $submitdiv = $wp_meta_boxes['duka']['side']['core']['submitdiv'];
            unset($wp_meta_boxes['duka']['side']['core']['submitdiv']);
            $new_core['submitdiv'] = $submitdiv;
            $new_core['postimagediv'] = $imagediv;
            $wp_meta_boxes['duka']['side']['core'] = array_merge($new_core, $wp_meta_boxes['duka']['side']['core']);

            //filter title
            $wp_meta_boxes['duka']['side']['core']['postimagediv']['title'] = __('Product Image', 'dp-lang');
        }
    }

    //Save our post meta when a product is created or updated
    static function save_product_meta($post_id) {

        //skip quick edit
        if (defined('DOING_AJAX')) return;

        if (!wp_verify_nonce(@$_POST['dukapress_noncename'], plugin_basename(__FILE__))) return;

        // Check permissions
        if ('duka' == $_POST['post_type']) {
            if (!current_user_can('edit_page', $post_id)) return $post_id;
        }
        else {
            if (!current_user_can('edit_post', $post_id)) return $post_id;
        }

        // for price
        if (NULL == $_POST['price']) {

        //do nothing

        }
        else {
            $content_price = $_POST['price'];

            update_post_meta($post_id, 'price', $content_price);
        }

        // for new price
        if (NULL == $_POST['new_price']) {

        //do nothing

        }
        else {
            $content_price = $_POST['new_price'];

            update_post_meta($post_id, 'new_price', $content_price);
        }

        // for stocks
        if (NULL == $_POST['currently_in_stock']) {

        //do nothing

        }
        else {
            $content_stock = $_POST['currently_in_stock'];
            update_post_meta($post_id, 'currently_in_stock', $content_stock);
        }

        // for weights
        if (NULL == $_POST['item_weight']) {

        //do nothing

        }
        else {
            $content_weight = $_POST['item_weight'];
            update_post_meta($post_id, 'item_weight', $content_weight);
        }

        //for file
        if (NULL == $_POST['digital_file']) {

        //do nothing

        }
        else {
            $content_file = $_POST['digital_file'];
            update_post_meta($post_id, 'digital_file', $content_file);
        }

        // SKU
        if (NULL == $_POST['sku']) {

        //do nothing

        }
        else {
            $sku = $_POST['sku'];
            update_post_meta($post_id, 'sku', $sku);
        }

        // for affiliate URL
        if (NULL == $_POST['affiliate_url']) {

        //do nothing

        }
        else {
            $affiliate_url = $_POST['affiliate_url'];
            update_post_meta($post_id, 'affiliate_url', $affiliate_url);
        }
		
		do_action('dukapress_save_product_meta',$post_id); //Custom actions
    }

    static function meta_details($post) {
        wp_nonce_field(plugin_basename(__FILE__), 'dukapress_noncename');
        $post_id = $post->ID;
        $content_price = get_post_meta($post_id, 'price', true);
        $new_price = get_post_meta($post_id, 'new_price', true);
        $content_stock = get_post_meta($post_id, 'currently_in_stock', true);
        $content_weight = get_post_meta($post_id, 'item_weight', true);
        $content_file = get_post_meta($post_id, 'digital_file', true);
        $affiliate_url = get_post_meta($post_id, 'affiliate_url', true);
        $sku = get_post_meta($post_id, 'sku', true);
        ?>
        <table class="widefat">
            <tr>
                <td><?php
                    _e('Price', 'dp-lang'); ?> :</td>
                <td>
					<input type="text" value="<?php echo $content_price; ?>" name="price" id="price" />
					<?php do_action('dukapress_product_edit_price',$post_id); ?>
				</td>
            </tr>
			<?php do_action('dukapress_after_product_edit_price',$post_id); ?>
            <tr>
                <td><?php _e('New Price', 'dp-lang'); ?> :</td>
                <td>
					<input type="text" value="<?php echo $new_price; ?>" name="new_price" id="new_price" />
					<?php do_action('dukapress_product_edit_new_price',$post_id); ?>
				</td>
            </tr>
			<?php do_action('dukapress_after_product_edit_new_price',$post_id); ?>
            <tr>
                <td><?php _e('Currently In Stock', 'dp-lang'); ?> :</td>
                <td><input type="text" value="<?php echo $content_stock; ?>" name="currently_in_stock" id="currently_in_stock"></td>
            </tr>
            <tr>
                <td><?php _e('Item Weight', 'dp-lang'); ?> :</td>
                <td><input type="text" value="<?php  echo $content_weight; ?>" name="item_weight" id="item_weight"></td>
            </tr>
            <tr>
                <td><?php _e('SKU', 'dp-lang'); ?> :</td>
                <td><input type="text" value="<?php  echo $sku; ?>" name="sku" id="sku"></td>
            </tr>
            <tr>
                <td><?php _e('Affiliate URL', 'dp-lang'); ?> :</td>
                <td><input type="text" value="<?php echo $affiliate_url; ?>" name="affiliate_url" id="affiliate_url"></td>
            </tr>
            <tr>
                <td><?php  _e('Digital File URL', 'dp-lang'); ?> :</td>
                <td>
                    <input type="text" value="<?php echo $content_file; ?>" name="digital_file" id="digital_file"><br/>
                    <input id="duka_upload_button" class="button-secondary" type="button" value="<?php  _e('Upload File', 'dp-lang'); ?>" />
                </td>
            </tr>
        </table>
        <div class="clear"></div>
        <?php
    }
    
    /**
     * Variation Meta Details
     *
     */
    static function variation_meta_details($post) {
        $post_id = $post->ID;
        add_thickbox(); ?>
        <a href="#TB_inline?width=756&height=550&inlineId=variation-options-modal" class="thickbox button"><?php _e('Add Variations', "dp-lang"); ?></a>	
        <div id="variation-options-modal" style="display:none;">
            <h3><b><?php _e('Dropdown Options', "dp-lang"); ?></b> <input type="button" id="dp_addVariation" value="<?php _e('Add', "dp-lang"); ?>" class="button tagadd"></h3>
            <div style="padding:10px;">
            <?php
                $variations = get_terms('duka_variation','orderby=id&hide_empty=0' ); 
                if ( ! empty( $variations ) && ! is_wp_error( $variations ) ){
                ?> 
                    <p class="submit">
                        <input class='button button-primary dp_saveVariations' type='button' value='<?php _e('Save Options','dp-lang'); ?>'/>
                    </p> 
                    <table class="widefat variation_lists">
                        <tr>
                            <td width="30%">
                                <select data-placeholder="<?php _e('Select option Name', "dp-lang"); ?>" class="chosen-select" tabindex="2" style="width:100%" id="vname1">
                                    <option value=""></option>
                                    <?php
                                    foreach ($variations  as $variation ) {
                                        ?><option value="<?php echo $variation->term_id; ?>"><?php echo $variation->name; ?></option><?php
                                    }
                                    ?>
                                </select>
                            </td>
                            <td>
                                <input type="text" class="optionname" id="value1" name="value1"/>
                            </td>
                            <td width="1%" style="padding:4px">&nbsp;</td>
                        </tr>
                    </table>
                    <p class="submit">
                        <input class='button button-primary dp_saveVariations' type='button' value='<?php _e('Save Options','dp-lang'); ?>'/>
                    </p>

                    <table class="widefat variation_appends" style="display:none">
                        <tr class="variation_data">
                            <td width="30%">
                                <select data-placeholder="<?php _e('Select option Name', "dp-lang"); ?>" class="hiddenchosen-select" tabindex="2" style="width:100%" id="vname1">
                                    <option value=""></option>
                                    <?php
                                    foreach ($variations  as $variation ) {
                                        ?><option value="<?php echo $variation->term_id; ?>"><?php echo $variation->name; ?></option><?php
                                    }
                                    ?>
                                </select>
                            </td>
                            <td>
                                <input type="text" class="hiddenoptionname" id="value1" name="value1"/>
                            </td>
                            <td width="1%" style="padding:4px"><img class="dp_removeVariation" style="height:20px; margin-top: 45px; cursor:pointer" class="remove-variation" src="<?php echo DPSC_DUKAPRESS_RESOURCEURL.'/img/close.png'; ?>" /></td>
                        </tr>
                    </table>
                    <script type="text/javascript">
                        jQuery(document).ready(function($) {
                            $('.chosen-select').data("placeholder",'<?php _e('Select Variation', "dp-lang"); ?>').chosen({});
                            $('.optionname').tagsInput({width:'98%',  defaultText : '<?php _e('Add variation then press enter', "dp-lang"); ?>'});
                            $('.chosen-container').css('width','100%');
                            setTimeout(function(){ $('#TB_ajaxContent').attr('style',''); $('#TB_ajaxContent').css('width','96%').css('height','530px');}, 3000);

                        });
                    </script>

            <?php } else{
                _e('No variations found', "dp-lang");
            } 
            ?></div>
        </div><br/><br/>
        <input type="hidden" class="dpsc_resources_url_img" value="<?php echo DPSC_DUKAPRESS_RESOURCEURL.'/img/update.gif'; ?>"/>
        <div class="variation_table_list">
        <?php
        echo self::variation_table($post_id);
        ?></div><?php
    }
    
    /**
     * Variation list table
     *
     */
    static function variation_table($post_id){
        $content_opname = get_post_meta($post_id, 'dropdown_option', true);
        $variation_table = '';
        if ($content_opname) {
            $optionnames = explode("||", $content_opname);
            $variation_table .= '<table class="widefat">';
            foreach ($optionnames as $optionname) {
                $optionvalue = explode("|", $optionname);
                if(is_numeric($optionvalue[0])){
                    $variation_name = dpsc_variation_name($optionvalue[0]);
                    $variation_table .= '<h3>'.$variation_name.'<img class="dp_removeSingleVariation" style="height:20px;cursor:pointer;float:right" class="remove-variation" src="'.DPSC_DUKAPRESS_RESOURCEURL.'/img/close.png" data-id="'.$optionname.'" title="'.__('Delete','dp-lang').' '.$variation_name.'"/></h3> ' ;
                    $variation_table .= '<table class="widefat">';
                    $variation_table .= '<thead>';
                    $variation_table.= '<tr>';
                    $variation_table.= '<td>'.__('Name','dp-lang').'</td>';
                    $variation_table.= '<td>'.__('Price','dp-lang').'</td>';
                    
                    $variation_table.= '</tr>';
                    $variation_table .= '</thead>';
                    $variation_table .= '<tbody>';
                    for ($i = 1; @$optionvalue[$i]; $i++) {
                        $variation_table.= '<tr>';
                        $vvalue = explode(";", $optionvalue[$i]);
                        $k = 0;
                        foreach ($vvalue as $value) {
                            $value = $vvalue[$k];
                            if($k == 1){
                                $variation_table.= '<td><input type="text" value="' . $value . '" />';
                                $variation_table.= ' <a href="javascript:void(0)" data-parent-id="'.$optionname.'" data-id="'.($i).'" class="button-primary dp_saveSingleVariation">'.__('Update','dp-lang').'</a>';
                                $variation_table.= ' <a href="javascript:void(0)" data-parent-id="'.$optionname.'" data-id="'.($i).'" class="button-secondary dp_removeSingleVariationOption">'.__('Delete','dp-lang').'</a></td>';
                            }else{
                                $variation_table.= '<td>' . $value . '</td>';
                            }
                            $k++;
                        }
                        $variation_table.= '</tr>';
                        
                    }
                    $variation_table .= '</tbody>';
                    $variation_table .= '</table>';
                }
            }
            
        }
        $variation_table .= '';
        return $variation_table;
    }

   

    /**
    * Save Variation Data
    */
    static function varition_save_data() {
        $counter = $_POST['counter'];
        $postid = $_POST['postid'];
        $prev_option = get_post_meta($postid, 'dropdown_option', true);

        // making || in each option name
        if ($prev_option) {
            $prev_option_new = $prev_option;
            $varition_type.= $prev_option_new;
        }

        // check for the validation that, option name should not be null
        for ($i = 1; $i <= $counter; $i++) {
            if ($_POST['vname' . $i]) {
                $varition_type.= $_POST['vname' . $i] . '|';
                $value = $_POST['value' . $i];
                $vvalue = explode(",", $value);
                foreach ($vvalue as $dvalue) {
                    $varition_type.= $dvalue . ';' . '0' . '|';
                }
                $varition_type.= '||';

            }
        }
        $varition_type = substr($varition_type, 0, ($len - 1));
        update_post_meta($postid, 'dropdown_option', $varition_type);
        
        $response = array('status' => true,
                         'message' => __('Success', "dp-lang"),
                         'data' => $varition_type);
        
        echo self::variation_table($postid);
        die();
    }

    /**
    * Delete Variation Data
    */
    static function varition_delete_data() {
        $postid = $_POST['postid'];
        $substr = $_POST['name'];

        $parent_str = get_post_meta($postid, 'dropdown_option', true);
        
        $parent_str = explode("||", $dropdown_option);
        $key = array_search($parentid, $parent_str);
        unset($parent_str[$key]);
        update_post_meta($postid, 'dropdown_option', $parent_str);
        echo self::variation_table($postid);
        die();
    }
    
    /**
     * Delete Variation data option
     */
    static function vaiation_delete_data_option(){
        $postid = $_POST['postid'];
        $parentid = $_POST['parentid'];
        $pos = $_POST['position'];
        
        $dropdown_option = get_post_meta($postid, 'dropdown_option', true);
        
        $parent_str = explode("||", $dropdown_option);
        $key = array_search($parentid, $parent_str);
        $value = $parent_str[$key];
        if($value){
            $optionvalue = explode("|", $value);
            unset($optionvalue[$pos]);
            $str = implode("|",$optionvalue);
            $parent_str[$key] = $str;
            $str = implode("||",$parent_str);
            update_post_meta($postid, 'dropdown_option', $str);
        }
        
        
        
        echo self::variation_table($postid);
        die();
    }
    
    /**
     * Update Variation Option Price
     *
     */
    static function vaiation_update_data_option(){
        $postid = $_POST['postid'];
        $parentid = $_POST['parentid'];
        $pos = $_POST['position'];
        $price = $_POST['price'];
        
        $dropdown_option = get_post_meta($postid, 'dropdown_option', true);
        
        $parent_str = explode("||", $dropdown_option);
        $key = array_search($parentid, $parent_str);
        $value = $parent_str[$key];
        if($value){
            $optionvalue = explode("|", $value);
            $vvalue = explode(";", $optionvalue[$pos]);
            $vvalue[1] = $price;
            $optionvalue[$pos] = implode(";",$vvalue);
            $str = implode("|",$optionvalue);
            $parent_str[$key] = $str;
            $str = implode("||",$parent_str);
            update_post_meta($postid, 'dropdown_option', $str);
        }
        echo self::variation_table($postid);
        die();
    }
    
    //Change status ajax function
    static function change_order_status(){
        global $dukapress;
        $order_id = trim($_POST['postid']);
        $status = trim($_POST['status']);
        $dukapress->change_order_status($order_id, $status);
        
        $order_status = __('Received', 'dp-lang');
        if ($status == 'order_received')
            $order_status = __('Received', 'dp-lang');
        else if ($status == 'order_paid')
            $order_status = __('Paid', 'dp-lang');
        else if ($status == 'order_shipped')
            $order_status = __('Shipped', 'dp-lang');
        else if ($status == 'order_closed')
            $order_status = __('Closed', 'dp-lang');
        else if ($status == 'trash')
            $order_status = __('Trashed', 'dp-lang');
        
        die($order_status);
    }
    
    /**
     * Order Meta Box
     */
    static function order_meta_boxes(){
        add_meta_box('duka_order-meta-details', __('Order Details', 'dp-lang'), array(__CLASS__, 'order_meta_details'), 'duka_order', 'normal', 'high');
    }
    
    /**
     * Order Meta Box Details
     */
    static function order_meta_details($post) {
        global $dukapress;
        
        $meta = get_post_custom();

        //unserialize
        foreach ($meta as $key => $val)
            $meta[$key] = array_map('maybe_unserialize', $val);
        
        $order_status = __('Received', 'dp-lang');
        if ($post->post_status == 'order_received')
            $order_status = __('Received', 'dp-lang');
        else if ($post->post_status == 'order_paid')
            $order_status = __('Paid', 'dp-lang');
        else if ($post->post_status == 'order_shipped')
            $order_status = __('Shipped', 'dp-lang');
        else if ($post->post_status == 'order_closed')
            $order_status = __('Closed', 'dp-lang');
        else if ($post->post_status == 'trash')
            $order_status = __('Trashed', 'dp-lang');
        
        $title = _draft_or_post_title();
        
        $t_time = get_the_time(__('Y/m/d g:i:s A'));
        $m_time = $post->post_date;
        $time = get_post_time('G', true, $post);

        $time_diff = time() - $time;

        if ($time_diff > 0 && $time_diff < 24 * 60 * 60) $h_time = sprintf(__('%s ago'), human_time_diff($time));
        else $h_time = mysql2date(__('Y/m/d'), $m_time);
        
        $total_items = number_format_i18n($meta["duka_order_items"][0]);
        
        $total_order = $meta["duka_order_total"][0];
        
        $payment_method = $meta["dpsc_payment_info"][0]['name'];
        $create_pdf = $dukapress->get_setting( 'pdf_generation' );
        $file_name = 'invoice_' . $title . '.pdf';
        if($create_pdf && file_exists(DPSC_PDF_CONTENT_DIR.'/'.$file_name)){
            
            ?>
            <a href="<?php echo DPSC_PDF_CONTENT_URL.'/'.$file_name; ?>" target="_blank"><?php _e("Download PDF Invoice","dp-lang"); ?></a>
            <?php
        }
        ?>
        <table width="100%" border="0" class="form-table">
            <tr>
                <th align="left" scope="row"><?php _e("Invoice","dp-lang"); ?></th><td><?php echo $title; ?></td>
            </tr>
            <tr>
                <th align="left" scope="row"><?php _e("Date Received","dp-lang"); ?></th><td><?php echo $h_time; ?></td>
            </tr>
            <tr>
                <th align="left" scope="row"><?php _e("Total Items","dp-lang"); ?></th><td><?php echo $total_items; ?></td>
            </tr>
            <tr>
                <th align="left" scope="row"><?php _e("Total Tax","dp-lang"); ?></th><td><?php echo $dukapress->format_currency('', $meta["duka_tax_total"][0]); ?></td>
            </tr>
            <tr>
                <th align="left" scope="row"><?php _e("Total Discount","dp-lang"); ?></th>
                <td>
                    <?php 
                        if (isset($meta["duka_discount_info"][0]) && $meta["duka_discount_info"][0]) {
                            echo $meta["duka_discount_info"][0]['discount'] . ' (' . strtoupper($meta["duka_discount_info"][0]['code']) . ')';
                        }
                        else {
                          _e('N/A', 'dp-lang');
                        }
                    ?>
                </td>
            </tr>
            <tr>
                <th align="left" scope="row"><?php _e("Total Shipping","dp-lang"); ?></th>
                <td>
                    <?php 
                        if(isset($meta["duka_shipping_total"]))
                            echo $dukapress->format_currency('', $meta["duka_shipping_total"][0]);
                        else
                            _e('N/A', 'dp-lang');
                    ?>
                </td>
            </tr>
            <tr>
                <th align="left" scope="row"><?php _e("Total Amount","dp-lang"); ?></th><td><?php echo $dukapress->format_currency( '',$total_order); ?></td>
            </tr>
            <tr>
                <th align="left" scope="row"><?php _e("Payment Method","dp-lang"); ?></th><td><?php echo $payment_method; ?></td>
            </tr>
            <tr>
                <th align="left" scope="row"><?php _e("Order Status","dp-lang"); ?></th><td class="dpsc_order_status"><?php echo $order_status; ?></td>
            </tr>
            <tr>
                <th align="left" scope="row"><?php _e("Actions","dp-lang"); ?></th>
                <td>
                    <?php
                    if ($post->post_status == 'order_received'){
                        if(isset($meta["dpsc_user_info"][0])){
                            $fnames = "";
                            $em = "";
                            $firstname =  array_search('dpsc_firstname', array_column($meta["dpsc_user_info"][0], 'uname'));
                            if($firstname !== FALSE ){
                                $fnames = $meta["dpsc_user_info"][0][$firstname]['value'];
                            }
                            $lastname =  array_search('dpsc_lastname', array_column($meta["dpsc_user_info"][0], 'uname'));
                            if($lastname !== FALSE ){
                                $fnames  .= " ".$meta["dpsc_user_info"][0][$lastname]['value'];
                            }
                            $email =  array_search('dpsc_email', array_column($meta["dpsc_user_info"][0], 'uname'));
                            if($email !== FALSE ){
                                $em = $meta["dpsc_user_info"][0][$email]['value'];
                            }
                            echo '<a href="mailto:' . urlencode($fnames) . ' &lt;' . esc_attr($em) . '&gt;?subject=' . urlencode(sprintf(__('Regarding Your Order (%s)', 'dp-lang'), $post->post_title)) . '">' . __("Email Reminder","dp-lang") . '</a>';
                        }
                    }
                    ?>
                    <select class="dpsc_change_order_status">
                        <option value="order_received" <?php selected($post->post_status, 'order_received'); ?>><?php _e('Change To Received','dp-lang'); ?></option>
                        <option value="order_paid" <?php selected($post->post_status, 'order_paid'); ?>><?php _e('Change To Paid','dp-lang'); ?></option>
                        <option value="order_shipped" <?php selected($post->post_status, 'order_shipped'); ?>><?php _e('Change To Shipped','dp-lang'); ?></option>
                        <option value="order_closed" <?php selected($post->post_status, 'order_closed'); ?>><?php _e('Change To Closed','dp-lang'); ?></option>
                        <option value="trash" <?php selected($post->post_status, 'trash'); ?>><?php _e('Change To Trashed','dp-lang'); ?></option>
                    </select>
                    <script type="text/javascript">
                        jQuery(document).ready(function($) {
                            $(document).on('change', 'select.dpsc_change_order_status', function(e) {
                                $.ajax({
                                    type: "POST",
                                    url: ajaxurl,
                                    data: {'action' : 'dpsc_order_status', 'status' : $(this).val(), 'postid' : '<?php echo $post->ID; ?>'},
                                    success: function (response) {
                                        $('.dpsc_order_status').html(response);
                                    }
                                });
                            });
                        });
                    </script>
                </td>
            </tr>
        </table>
        <hr/>
        <?php
            $cart = $meta["dpsc_cart_info"][0];
        ?>
        <h2 class="title"><strong><?php _e("Product Information","dp-lang"); ?></strong></h2>
        <table width="100%" border="0" class="widefat">
            <thead>
                <tr>
                    <th align="left" scope="col"><?php _e("Name","dp-lang"); ?></th>
                    <th align="left" scope="col"><?php _e("Quantity","dp-lang"); ?></th>
                    <th align="left" scope="col"><?php _e("Unit Price","dp-lang"); ?></th>
                    <th align="left" scope="col"><?php _e("Total Price","dp-lang"); ?></th>
                </tr>
            </thead>
            <tbody>
            <?php
            foreach ($cart as $key => $dpsc_product) {
                $product = get_post($dpsc_product['item_number']);
                $dpsc_var = '';
                if (!empty($dpsc_product['var'])) {
                    $dpsc_var = ' (' . $dpsc_product['var'] . ')';
                }
                $edit_link = get_edit_post_link($dpsc_product['item_number']);
                $prod_price = $dpsc_product['price'] * $dpsc_product['quantity'];
                ?>
                <tr>
                    <td>
                        <a href="<?php echo $edit_link; ?>" target="_blank" title="<?php _e('View','dp-lang'); ?> <?php echo $product->post_title.$dpsc_var; ?>"><?php echo $product->post_title; ?></a>
                    </td>
                    <td><?php echo $dpsc_product['quantity']; ?></td>
                    <td><?php echo $dukapress->format_currency( '',$dpsc_product['price']); ?></td>
                    <td><?php echo $dukapress->format_currency( '', $prod_price ); ?></td>
                </tr>
                <?php
            }
            ?>
            </tbody>
        </table>
        <hr/>
        <table>
            <tr>
                <td width="50%" style="border-right:1px solid #cccccc">
                   <h2 class="title"><strong><?php _e("Customer Information","dp-lang"); ?></strong></h2>
                    <table width="100%" border="0" class="form-table">
                        <?php
                            $user_info = $meta["dpsc_user_info"][0];
                            foreach($user_info as $key => $value){
                                ?>
                                <tr>
                                    <th align="left" scope="row"><?php echo $value['name']; ?></th><td><?php echo $value['value']; ?></td>
                                </tr>
                                <?php
                            }
                        ?>
                    </table> 
                </td>
                <td width="48%" style="padding-left:1%">
                    <?php
                        $shipping_info = $meta["dpsc_shipping_info"][0];
                        if(is_array($shipping_info)){
                            ?>
                            <h2 class="title"><strong><?php _e("Shipping Information","dp-lang"); ?></strong></h2>
                            <table width="100%" border="0" class="form-table">
                            <?php
                            foreach($shipping_info as $key => $value){
                                ?>
                                <tr>
                                    <th align="left" scope="row"><?php echo $value['name']; ?></th><td><?php echo $value['value']; ?></td>
                                </tr>
                                <?php
                            }
                            ?>
                            </table>   
                            <?php

                        }
                    ?>
                </td>
            </tr>
        </table>
        
        <?php
    }
}
?>
