<?php

if(!class_exists('DukaPress_Product_Widget')) {
	add_action('widgets_init', create_function('', 'return register_widget("DukaPress_Product_Widget");'));
	
	/**
	 * Widget for products
	 */
	class DukaPress_Product_Widget extends WP_Widget{
	
		function __construct() {
			$widget_ops = array('classname' => 'dukapress_product', 'description' => __('Product Display',"dp-lang"));
			parent::__construct( 'dukapress_products_widget', __('DukaPress Product Display'), $widget_ops);
		}
		
		function form($instance) {
			$instance = wp_parse_args( (array) $instance, array(  'title' => '', 'number' => '','thumbnail' => '', 'atc' => '', 'post_category' => '') );
			$title = esc_attr( $instance['title'] );
			$number = esc_attr( $instance['number'] );
			$thumbnail = esc_attr( $instance['thumbnail'] );
			$buy_now = esc_attr( $instance['buy_now'] );
			$width = esc_attr( $instance['width'] );
			$height = esc_attr( $instance['height'] );
			$atc = esc_attr( $instance['atc'] );
			$category = esc_attr($instance['category']);
			?>
			<p>
				<label for="<?php echo $this->get_field_id('title'); ?>"><?php _e("Title","dp-lang");?>:</label>
				<input type="text" value="<?php echo $title; ?>" name="<?php echo $this->get_field_name('title'); ?>" id="<?php echo $this->get_field_id('title'); ?>" class="widefat" />
			</p>
			<p>
				<label for="<?php echo $this->get_field_id('number'); ?>"><?php _e("Number of products to display","dp-lang");?>:</label>
				<input type="text" value="<?php echo $number; ?>" name="<?php echo $this->get_field_name('number'); ?>" id="<?php echo $this->get_field_id('number'); ?>" class="widefat" />
			</p>
			<p>
				<label for="<?php echo $this->get_field_id('category'); ?>"><?php _e("Category ID","dp-lang");?> (<small><?php _e("comma separated. e.g.","dp-lang");?> <i>1,2,3</i></small>):</label>
				<input type="text" value="<?php echo $category; ?>" name="<?php echo $this->get_field_name('category'); ?>" id="<?php echo $this->get_field_id('category'); ?>" class="widefat" />
			</p>

			<p>
				<label><?php _e("Show Thumbnail","dp-lang");?>:</label>
				<select name="<?php echo $this->get_field_name('thumbnail'); ?>">
					<option value="yes" <?php selected( $thumbnail, 'yes'); ?> ><?php _e("Yes","dp-lang");?></option>
					<option value="no" <?php selected( $thumbnail, 'no'); ?>><?php _e("No","dp-lang");?></option>
				</select>
			</p>
			<p>
				<label for="<?php echo $this->get_field_id('width'); ?>"><?php _e("Thumbnail Width","dp-lang");?>:</label>
				<input type="text" value="<?php echo $width; ?>" name="<?php echo $this->get_field_name('width'); ?>" id="<?php echo $this->get_field_id('width'); ?>" class="widefat" />
			</p>
			<p>
				<label for="<?php echo $this->get_field_id('height'); ?>"><?php _e("Thumbnail Height","dp-lang");?>:</label>
				<input type="text" value="<?php echo $height; ?>" name="<?php echo $this->get_field_name('height'); ?>" id="<?php echo $this->get_field_id('height'); ?>" class="widefat" />
			</p>
			<p>
				<label><?php _e("Show Add to Cart","dp-lang");?>:</label>
				<select name="<?php echo $this->get_field_name('atc'); ?>">
					<option value="yes" <?php selected( $atc, 'yes'); ?>><?php _e("Yes","dp-lang");?></option>
					<option value="no" <?php selected( $atc, 'no'); ?>><?php _e("No","dp-lang");?></option>
				</select>
			</p>
			<p>
				<label><?php _e("Buy Now","dp-lang");?>:</label>
				<select name="<?php echo $this->get_field_name('buy_now'); ?>">
					<option value="no" <?php selected( $buy_now, 'no'); ?>><?php _e("No","dp-lang");?></option>
					<option value="yes" <?php selected( $buy_now, 'yes'); ?>><?php _e("Yes","dp-lang");?></option>
				</select>
			</p>
			<?php
		}
		
		function update($new_instance, $old_instance) {
			$instance = $old_instance;
			$instance['title'] = strip_tags( $new_instance['title'] );
			$instance['number'] = strip_tags( $new_instance['number'] );
			$instance['thumbnail'] = strip_tags( $new_instance['thumbnail'] );
			$instance['width'] = strip_tags( $new_instance['width'] );
			$instance['height'] = strip_tags( $new_instance['height'] );
			$instance['atc'] = strip_tags( $new_instance['atc'] );
			$instance['buy_now'] = strip_tags( $new_instance['buy_now'] );
			$instance['category'] = strip_tags( $new_instance['category'] );
			return $instance;
		}
		
		function widget($args, $instance) {
			extract($args);
			$title = empty( $instance['title'] ) ? __('DukaPress Products',"dp-lang") : __($instance['title'],"dp-lang");
			echo $before_widget;
			echo $before_title.$title.$after_title;
			$widget_products = get_posts('post_type=duka&numberposts=' . $instance['number'] . '&category=' . $instance['category'] . 'orderby=post_date&order=DESC');
			$show_image = ($instance['thumbnail'] === 'yes');
			$direct_checkout = ($instance['buy_now'] === 'yes');
			$widget_html = "";
			if (is_array($widget_products)) {
				$widget_html .= '<div class="dp_products_widget">';
				foreach ($widget_products as $product) {
					$output = dukapress_product_detail($product->ID);
					$widget_html .= '<div class="dp_widget_product">';
					$prod_permalink = get_permalink($product->ID);
					if ($show_image) {
						$attachment_images = get_children('post_type=attachment&post_status=inherit&post_mime_type=image&post_parent=' . $product->ID);
						$main_image = '';
						foreach ($attachment_images as $image) {
							$main_image = $image->guid;
							break;
						}
						if (!empty($main_image)) {
							$widget_html .= '<div class="dp_widget_product_image">';
							$widget_html .= '<a href="' . $prod_permalink . '" title="' .$product->post_title . '"><img src="' . dp_img_resize('', $main_image, $instance['width'], $instance['height']). '" ></a>';
							$widget_html .= '</div>';
						}else{
							$widget_html .= '<div class="dp_widget_product_image">';
							$widget_html .= '<a href="' . $prod_permalink . '" title="' . $product->post_title . '"><img src="' . DPSC_DUKAPRESS_RESOURCEURL. '/img/default_product_small.jpg" style="width:'.$instance['width'].' px; height:'.$instance['height'].'"></a>';
							$widget_html .= '</div>';
						}
					}
					$widget_html .= '<div class="dp_widget_product_detail">';
					$widget_html .= '<p class="title"><a href="' . $prod_permalink . '" title="' .$product->post_title . '">' . $product->post_title . '</a></p>';
					if ($instance['atc'] === 'yes') {
						$widget_html .= dukapress_product_cart_action($output,$direct_checkout,false);
					}
					$widget_html .= '</div>';
					$widget_html .= '</div>';
				}
				$widget_html .= '</div>';
				echo $widget_html;
			}
			echo $after_widget;
		}
	}
}
?>